@@ -1,4 +1,7 @@
-/* SPDX-License-Identifier: GPL-2.0-only */
+// SPDX-FileCopyrightText: 2012 Andrew Gabbasov <andrew_gabbasov@mentor.com>
+//
+// SPDX-License-Identifier: GPL-2.0-only
+
 #undef TRACE_SYSTEM
 #define TRACE_SYSTEM compaction
 
@@ -9,8 +12,6 @@
 #include <linux/types.h>
 #include <lttng/kernel-version.h>
 
-#if LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(4,0,0)
-
 LTTNG_TRACEPOINT_EVENT_CLASS(compaction_isolate_template,
 
 	TP_PROTO(unsigned long start_pfn,
@@ -56,47 +57,6 @@ LTTNG_TRACEPOINT_EVENT_INSTANCE_MAP(compaction_isolate_template,
 	TP_ARGS(start_pfn, end_pfn, nr_scanned, nr_taken)
 )
 
-#else /* #if LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(4,0,0) */
-
-LTTNG_TRACEPOINT_EVENT_CLASS(compaction_isolate_template,
-
-	TP_PROTO(unsigned long nr_scanned,
-		unsigned long nr_taken),
-
-	TP_ARGS(nr_scanned, nr_taken),
-
-	TP_FIELDS(
-		ctf_integer(unsigned long, nr_scanned, nr_scanned)
-		ctf_integer(unsigned long, nr_taken, nr_taken)
-	)
-)
-
-LTTNG_TRACEPOINT_EVENT_INSTANCE_MAP(compaction_isolate_template,
-
-	mm_compaction_isolate_migratepages,
-
-	compaction_isolate_migratepages,
-
-	TP_PROTO(unsigned long nr_scanned,
-		unsigned long nr_taken),
-
-	TP_ARGS(nr_scanned, nr_taken)
-)
-
-LTTNG_TRACEPOINT_EVENT_INSTANCE_MAP(compaction_isolate_template,
-
-	mm_compaction_isolate_freepages,
-
-	compaction_isolate_freepages,
-
-	TP_PROTO(unsigned long nr_scanned,
-		unsigned long nr_taken),
-
-	TP_ARGS(nr_scanned, nr_taken)
-)
-
-#endif /* #else #if LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(4,0,0) */
-
 #if (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(6,9,0))
 LTTNG_TRACEPOINT_EVENT_MAP(mm_compaction_migratepages,
 
@@ -144,9 +104,7 @@ LTTNG_TRACEPOINT_EVENT_MAP(mm_compaction_migratepages,
 		ctf_integer(unsigned long, nr_failed, nr_all - nr_succeeded)
 	)
 )
-#elif LTTNG_KERNEL_RANGE(3,12,30, 3,13,0) || \
-	LTTNG_KERNEL_RANGE(3,14,25, 3,15,0) || \
-	(LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(3,16,0))
+#else
 LTTNG_TRACEPOINT_EVENT_CODE_MAP(mm_compaction_migratepages,
 
 	compaction_migratepages,
@@ -182,21 +140,6 @@ LTTNG_TRACEPOINT_EVENT_CODE_MAP(mm_compaction_migratepages,
 
 	TP_code_post()
 )
-#else /* #if (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(3,16,0)) */
-LTTNG_TRACEPOINT_EVENT_MAP(mm_compaction_migratepages,
-
-	compaction_migratepages,
-
-	TP_PROTO(unsigned long nr_migrated,
-		unsigned long nr_failed),
-
-	TP_ARGS(nr_migrated, nr_failed),
-
-	TP_FIELDS(
-		ctf_integer(unsigned long, nr_migrated, nr_migrated)
-		ctf_integer(unsigned long, nr_failed, nr_failed)
-	)
-)
 #endif /* #else #if (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(3,16,0)) */
 
 #endif /* LTTNG_TRACE_COMPACTION_H */
