@@ -122,7 +122,7 @@ LTTNG_TRACEPOINT_EVENT_INSTANCE(writeback_folio_template, writeback_dirty_folio,
 	TP_ARGS(folio, mapping)
 )
 
-LTTNG_TRACEPOINT_EVENT_INSTANCE(writeback_folio_template, folio_wait_writeback,
+LTTNG_TRACEPOINT_EVENT_INSTANCE(writeback_folio_template, writeback_folio_wait,
 
 	TP_PROTO(struct folio *folio, struct address_space *mapping),
 
@@ -150,7 +150,7 @@ LTTNG_TRACEPOINT_EVENT_INSTANCE(writeback_page_template, writeback_dirty_page,
 	TP_ARGS(page, mapping)
 )
 
-LTTNG_TRACEPOINT_EVENT_INSTANCE(writeback_page_template, wait_on_page_writeback,
+LTTNG_TRACEPOINT_EVENT_INSTANCE(writeback_page_template, writeback_wait_on_page,
 
 	TP_PROTO(struct page *page, struct address_space *mapping),
 
@@ -268,6 +268,23 @@ DEFINE_WRITEBACK_EVENT(writeback_bdi_unregister)
 DEFINE_WRITEBACK_EVENT(writeback_thread_start)
 DEFINE_WRITEBACK_EVENT(writeback_thread_stop)
 
+#if (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(6,17,0))
+LTTNG_TRACEPOINT_EVENT_CLASS(writeback_wbc_class,
+	TP_PROTO(struct writeback_control *wbc, struct backing_dev_info *bdi),
+	TP_ARGS(wbc, bdi),
+	TP_FIELDS(
+		ctf_string(name, lttng_bdi_dev_name(bdi))
+		ctf_integer(long, nr_to_write, wbc->nr_to_write)
+		ctf_integer(long, pages_skipped, wbc->pages_skipped)
+		ctf_integer(int, sync_mode, wbc->sync_mode)
+		ctf_integer(int, for_kupdate, wbc->for_kupdate)
+		ctf_integer(int, for_background, wbc->for_background)
+		ctf_integer(int, range_cyclic, wbc->range_cyclic)
+		ctf_integer(long, range_start, (long) wbc->range_start)
+		ctf_integer(long, range_end, (long) wbc->range_end)
+	)
+)
+#else
 LTTNG_TRACEPOINT_EVENT_CLASS(writeback_wbc_class,
 	TP_PROTO(struct writeback_control *wbc, struct backing_dev_info *bdi),
 	TP_ARGS(wbc, bdi),
@@ -284,6 +301,7 @@ LTTNG_TRACEPOINT_EVENT_CLASS(writeback_wbc_class,
 		ctf_integer(long, range_end, (long) wbc->range_end)
 	)
 )
+#endif
 
 #undef DEFINE_WBC_EVENT
 #define LTTNG_TRACEPOINT_EVENT_WBC_INSTANCE(name, map) \
