@@ -18,7 +18,7 @@
  * should be increased when an incompatible ABI change is done.
  */
 #define LTTNG_KERNEL_ABI_MAJOR_VERSION		2
-#define LTTNG_KERNEL_ABI_MINOR_VERSION		6
+#define LTTNG_KERNEL_ABI_MINOR_VERSION		7
 
 #define LTTNG_KERNEL_ABI_SYM_NAME_LEN		256
 #define LTTNG_KERNEL_ABI_SESSION_NAME_LEN	256
@@ -130,16 +130,43 @@ struct lttng_kernel_abi_syscall {
 	uint32_t nr;		/* For LTTNG_SYSCALL_MATCH_NR */
 } __attribute__((packed));
 
+/*
+ * An immediate match requires that the requested event matches existing
+ * instrumentation when the ioctl is issued, whereas a lazy match does not
+ * have this constraint.
+ *
+ * Instrumentation                  default
+ * ---------------------------------------------------------------------------
+ * LTTNG_KERNEL_ABI_TRACEPOINT:     lazy
+ * LTTNG_KERNEL_ABI_SYSCALL:        lazy
+ * LTTNG_KERNEL_ABI_KPROBE:         immediate
+ * LTTNG_KERNEL_ABI_KRETPROBE:      immediate
+ * LTTNG_KERNEL_ABI_UPROBE:         immediate
+ */
+enum lttng_kernel_abi_match_check {
+	LTTNG_KERNEL_ABI_MATCH_DEFAULT = 0,
+	LTTNG_KERNEL_ABI_MATCH_IMMEDIATE = 1,
+	LTTNG_KERNEL_ABI_MATCH_LAZY = 2,
+};
+
+/*
+ * Extended event parameters.
+ */
+struct lttng_kernel_abi_event_ext {
+	uint32_t len;				/* length of this structure */
+
+	uint8_t match_check;			/* enum lttng_kernel_abi_match_check */
+}  __attribute__((packed));
+
 /*
  * For syscall tracing, name = "*" means "enable all".
  */
-#define LTTNG_KERNEL_ABI_EVENT_PADDING1	8
 #define LTTNG_KERNEL_ABI_EVENT_PADDING2	LTTNG_KERNEL_ABI_SYM_NAME_LEN + 32
 struct lttng_kernel_abi_event {
 	char name[LTTNG_KERNEL_ABI_SYM_NAME_LEN];	/* event name */
 	uint32_t instrumentation;		/* enum lttng_kernel_abi_instrumentation */
 	uint64_t token;				/* User-provided token */
-	char padding[LTTNG_KERNEL_ABI_EVENT_PADDING1];
+	uint64_t event_ext;			/* struct lttng_kernel_abi_event_ext */
 
 	/* Per instrumentation type configuration */
 	union {
@@ -160,7 +187,18 @@ struct lttng_kernel_abi_event_notifier {
 	char padding[LTTNG_KERNEL_ABI_EVENT_NOTIFIER_PADDING];
 } __attribute__((packed));
 
-#define LTTNG_KERNEL_ABI_COUNTER_DIMENSION_MAX	4
+#define LTTNG_KERNEL_ABI_EVENT_NOTIFIER_NOTIFICATION_PADDING 32
+struct lttng_kernel_abi_event_notifier_notification {
+	uint64_t token;
+	uint16_t capture_buf_size;
+	char padding[LTTNG_KERNEL_ABI_EVENT_NOTIFIER_NOTIFICATION_PADDING];
+} __attribute__((packed));
+
+enum lttng_kernel_abi_key_token_type {
+	LTTNG_KERNEL_ABI_KEY_TOKEN_STRING = 0,		/* arg: string_ptr. */
+	LTTNG_KERNEL_ABI_KEY_TOKEN_EVENT_NAME = 1,	/* no arg. */
+	LTTNG_KERNEL_ABI_KEY_TOKEN_PROVIDER_NAME = 2,	/* no arg. */
+};
 
 enum lttng_kernel_abi_counter_arithmetic {
 	LTTNG_KERNEL_ABI_COUNTER_ARITHMETIC_MODULAR = 0,
@@ -171,63 +209,173 @@ enum lttng_kernel_abi_counter_bitness {
 	LTTNG_KERNEL_ABI_COUNTER_BITNESS_64 = 1,
 };
 
-struct lttng_kernel_abi_counter_dimension {
-	uint64_t size;
-	uint64_t underflow_index;
-	uint64_t overflow_index;
-	uint8_t has_underflow;
-	uint8_t has_overflow;
+struct lttng_kernel_abi_key_token {
+	uint32_t len;				/* length of child structure. */
+	uint32_t type;				/* enum lttng_kernel_abi_key_token_type */
+	/*
+	 * The size of this structure is fixed because it is embedded into
+	 * children structures.
+	 */
 } __attribute__((packed));
 
-#define LTTNG_KERNEL_ABI_COUNTER_CONF_PADDING1	67
-struct lttng_kernel_abi_counter_conf {
-	uint32_t arithmetic;	/* enum lttng_kernel_abi_counter_arithmetic */
-	uint32_t bitness;	/* enum lttng_kernel_abi_counter_bitness */
+/* Length of this structure excludes the following string. */
+struct lttng_kernel_abi_key_token_string {
+	struct lttng_kernel_abi_key_token parent;
+	uint32_t string_len;		/* string length (includes \0) */
+
+	/* Null-terminated string of length @string_len follows this structure. */
+} __attribute__((packed));
+
+/*
+ * token types event_name and provider_name don't have specific fields,
+ * so they do not need to derive their own specific child structure.
+ */
+
+struct lttng_kernel_abi_counter_map_descriptor {
+	uint32_t len;			/* length of this structure. */
+
+	uint64_t descriptor_index;	/* Descriptor index (input: [ 0 .. nr_descriptors - 1 ]) */
+
+	uint32_t dimension;		/* Dimension indexed (output) */
+	uint64_t user_token;		/* User-provided 64-bit token (output) */
+	uint64_t key_string;		/*
+					 * Pointer (input) to key string associated with this index
+					 * (output). If key_string_len is smaller than the required
+					 * space, the ioctl fails with -ENOSPC, storing the required
+					 * string space into @key_string_len.
+					 */
+	uint32_t key_string_len;	/* Key string length (input/output, includes \0) */
+	uint64_t array_indexes;		/*
+					 * Pointer (input) to array of indexes within each dimension
+					 * (output). There are @dimension values populated.  Each
+					 * element is of type uint64_t.  If arrays_indexes_len is
+					 * smaller than @dimension, the ioctl fails with -ENOSPC,
+					 * storing the required array index length into
+					 * @array_index_len.
+					 */
+	uint32_t array_indexes_len;	/* Array indexes length (input/output). */
+} __attribute__((packed));
+
+/*
+ * Dimension indexing: All events should use the same key type to index
+ * a given map dimension.
+ */
+enum lttng_kernel_abi_key_type {
+	LTTNG_KERNEL_ABI_KEY_TYPE_TOKENS = 0,		/* Dimension key is a set of tokens. */
+	LTTNG_KERNEL_ABI_KEY_TYPE_INTEGER = 1,		/* Dimension key is an integer value. */
+};
+
+struct lttng_kernel_abi_counter_key_dimension {
+	uint32_t len;			/* length of child structure */
+	uint32_t key_type;		/* enum lttng_kernel_abi_key_type */
+	/*
+	 * The size of this structure is fixed because it is embedded
+	 * into children structures.
+	 */
+} __attribute__((packed));
+
+struct lttng_kernel_abi_counter_key_dimension_tokens {
+	struct lttng_kernel_abi_counter_key_dimension parent;
+	uint32_t nr_key_tokens;
+
+	/* Followed by an array of nr_key_tokens struct lttng_kernel_abi_key_token elements. */
+} __attribute__((packed));
+
+/*
+ * The "integer" key type is not implemented yet, but when it will be
+ * introduced in the future, its specific key dimension will allow
+ * defining the function to apply over input argument, bytecode to run
+ * and so on.
+ */
+
+enum lttng_kernel_abi_counter_action {
+	LTTNG_KERNEL_ABI_COUNTER_ACTION_INCREMENT = 0,
+
+	/*
+	 * Can be extended with additional actions, such as decrement,
+	 * set value, run bytecode, and so on.
+	 */
+};
+
+struct lttng_kernel_abi_counter_event {
+	uint32_t len;			/* length of this structure */
+	uint32_t action;		/* enum lttng_kernel_abi_counter_action */
+
+	struct lttng_kernel_abi_event event;
+	uint32_t number_key_dimensions;		/* array of dimensions is an array of var. len. elements. */
+
+	/*
+	 * Followed by additional data specific to the action, and by a
+	 * variable-length array of key dimensions.
+	 */
+} __attribute__((packed));
+
+enum lttng_kernel_abi_counter_dimension_flags {
+	LTTNG_KERNEL_ABI_COUNTER_DIMENSION_FLAG_UNDERFLOW = (1 << 0),
+	LTTNG_KERNEL_ABI_COUNTER_DIMENSION_FLAG_OVERFLOW = (1 << 1),
+};
+
+struct lttng_kernel_abi_counter_dimension {
+	uint32_t key_type;		/* enum lttng_kernel_abi_key_type */
+	uint32_t flags;			/* enum lttng_kernel_abi_counter_dimension_flags */
+	uint64_t size;			/* dimension size */
+	uint64_t underflow_index;
+	uint64_t overflow_index;
+} __attribute__((packed));
+
+struct lttng_kernel_abi_counter_dimension_array {
 	uint32_t number_dimensions;
+	uint32_t elem_len;		/* array stride (size of struct lttng_kernel_abi_counter_dimension) */
+	uint64_t ptr;			/* pointer to array of struct lttng_kernel_abi_counter_dimension */
+} __attribute__((packed));
+
+enum lttng_kernel_abi_counter_conf_flags {
+	LTTNG_KERNEL_ABI_COUNTER_CONF_FLAG_COALESCE_HITS = (1 << 0),
+};
+
+struct lttng_kernel_abi_counter_conf {
+	uint32_t len;			/* length of this structure */
+	uint32_t flags;			/* enum lttng_kernel_abi_counter_conf_flags */
+	uint32_t arithmetic;		/* enum lttng_kernel_abi_counter_arithmetic */
+	uint32_t bitness;		/* enum lttng_kernel_abi_counter_bitness */
 	int64_t global_sum_step;
-	struct lttng_kernel_abi_counter_dimension dimensions[LTTNG_KERNEL_ABI_COUNTER_DIMENSION_MAX];
-	uint8_t coalesce_hits;
-	char padding[LTTNG_KERNEL_ABI_COUNTER_CONF_PADDING1];
+	struct lttng_kernel_abi_counter_dimension_array dimension_array;
 } __attribute__((packed));
 
 struct lttng_kernel_abi_counter_index {
 	uint32_t number_dimensions;
-	uint64_t dimension_indexes[LTTNG_KERNEL_ABI_COUNTER_DIMENSION_MAX];
+	uint64_t ptr;			/* pointer to dimension indexes (array of uint64_t) */
 } __attribute__((packed));
 
+enum lttng_kernel_abi_counter_value_flags {
+	LTTNG_KERNEL_ABI_COUNTER_VALUE_FLAG_UNDERFLOW = (1 << 0),
+	LTTNG_KERNEL_ABI_COUNTER_VALUE_FLAG_OVERFLOW = (1 << 1),
+};
+
 struct lttng_kernel_abi_counter_value {
 	int64_t value;
-	uint8_t underflow;
-	uint8_t overflow;
+	uint32_t flags;			/* enum lttng_kernel_abi_counter_value_flags */
 } __attribute__((packed));
 
-#define LTTNG_KERNEL_ABI_COUNTER_READ_PADDING 32
+#ifdef CONFIG_LTTNG_EXPERIMENTAL_COUNTER
 struct lttng_kernel_abi_counter_read {
+	uint32_t len;			/* length of this structure */
 	struct lttng_kernel_abi_counter_index index;
 	int32_t cpu;	/* -1 for global counter, >= 0 for specific cpu. */
 	struct lttng_kernel_abi_counter_value value;	/* output */
-	char padding[LTTNG_KERNEL_ABI_COUNTER_READ_PADDING];
 } __attribute__((packed));
 
-#define LTTNG_KERNEL_ABI_COUNTER_AGGREGATE_PADDING 32
 struct lttng_kernel_abi_counter_aggregate {
+	uint32_t len;			/* length of this structure */
 	struct lttng_kernel_abi_counter_index index;
 	struct lttng_kernel_abi_counter_value value;	/* output */
-	char padding[LTTNG_KERNEL_ABI_COUNTER_AGGREGATE_PADDING];
 } __attribute__((packed));
 
-#define LTTNG_KERNEL_ABI_COUNTER_CLEAR_PADDING 32
 struct lttng_kernel_abi_counter_clear {
+	uint32_t len;			/* length of this structure */
 	struct lttng_kernel_abi_counter_index index;
-	char padding[LTTNG_KERNEL_ABI_COUNTER_CLEAR_PADDING];
-} __attribute__((packed));
-
-#define LTTNG_KERNEL_ABI_EVENT_NOTIFIER_NOTIFICATION_PADDING 32
-struct lttng_kernel_abi_event_notifier_notification {
-	uint64_t token;
-	uint16_t capture_buf_size;
-	char padding[LTTNG_KERNEL_ABI_EVENT_NOTIFIER_NOTIFICATION_PADDING];
 } __attribute__((packed));
+#endif	/* CONFIG_LTTNG_EXPERIMENTAL_COUNTER */
 
 struct lttng_kernel_abi_tracer_version {
 	uint32_t major;
@@ -248,6 +396,11 @@ struct lttng_kernel_abi_session_creation_time {
 	char iso8601[LTTNG_KERNEL_ABI_SESSION_CREATION_TIME_ISO8601_LEN];
 } __attribute__((packed));
 
+enum lttng_kernel_abi_session_output_format {
+	LTTNG_KERNEL_ABI_SESSION_OUTPUT_FORMAT_CTF_1_8 = 1,
+	LTTNG_KERNEL_ABI_SESSION_OUTPUT_FORMAT_CTF_2 = 2,
+};
+
 enum lttng_kernel_abi_calibrate_type {
 	LTTNG_KERNEL_ABI_CALIBRATE_KRETPROBE,
 };
@@ -393,12 +546,14 @@ struct lttng_kernel_abi_tracker_args {
 	_IOW(0xF6, 0x5D, struct lttng_kernel_abi_session_name)
 #define LTTNG_KERNEL_ABI_SESSION_SET_CREATION_TIME		\
 	_IOW(0xF6, 0x5E, struct lttng_kernel_abi_session_creation_time)
+#define LTTNG_KERNEL_ABI_SESSION_SET_OUTPUT_FORMAT _IOW(0xF6, 0x5F, uint32_t)
 
 /* Channel FD ioctl */
 /* lttng/abi-old.h reserve 0x60 and 0x61. */
 #define LTTNG_KERNEL_ABI_STREAM			_IO(0xF6, 0x62)
 #define LTTNG_KERNEL_ABI_EVENT			\
 	_IOW(0xF6, 0x63, struct lttng_kernel_abi_event)
+/* LTTNG_KERNEL_ABI_SYSCALL_MASK applies to both channel and counter fds. */
 #define LTTNG_KERNEL_ABI_SYSCALL_MASK		\
 	_IOWR(0xF6, 0x64, struct lttng_kernel_abi_syscall_mask)
 
@@ -412,9 +567,12 @@ struct lttng_kernel_abi_tracker_args {
 #define LTTNG_KERNEL_ABI_ENABLE			_IO(0xF6, 0x82)
 #define LTTNG_KERNEL_ABI_DISABLE			_IO(0xF6, 0x83)
 
-/* Trigger group and session ioctl */
+/* Event notifier group and session ioctl */
+
+/* (0xF6, 0x84) is reserved for old ABI. */
+
 #define LTTNG_KERNEL_ABI_COUNTER \
-	_IOW(0xF6, 0x84, struct lttng_kernel_abi_counter_conf)
+	_IOW(0xF6, 0x85, struct lttng_kernel_abi_counter_conf)
 
 /* Event and Event notifier FD ioctl */
 #define LTTNG_KERNEL_ABI_FILTER			_IO(0xF6, 0x90)
@@ -437,14 +595,24 @@ struct lttng_kernel_abi_tracker_args {
 /* Event notifier file descriptor ioctl */
 #define LTTNG_KERNEL_ABI_CAPTURE			_IO(0xF6, 0xB8)
 
-/* Counter file descriptor ioctl */
-#define LTTNG_KERNEL_ABI_COUNTER_READ \
-	_IOWR(0xF6, 0xC0, struct lttng_kernel_abi_counter_read)
-#define LTTNG_KERNEL_ABI_COUNTER_AGGREGATE \
-	_IOWR(0xF6, 0xC1, struct lttng_kernel_abi_counter_aggregate)
-#define LTTNG_KERNEL_ABI_COUNTER_CLEAR \
-	_IOW(0xF6, 0xC2, struct lttng_kernel_abi_counter_clear)
+/* (0xF6, {0xC0, 0xC1, 0xC2}) are reserved for old ABI. */
 
+/* Counter file descriptor ioctl */
+#define LTTNG_KERNEL_ABI_COUNTER_MAP_NR_DESCRIPTORS \
+	_IOR(0xF6, 0xC3, uint64_t)
+#define LTTNG_KERNEL_ABI_COUNTER_MAP_DESCRIPTOR \
+	_IOWR(0xF6, 0xC4, struct lttng_kernel_abi_counter_map_descriptor)
+#define LTTNG_KERNEL_ABI_COUNTER_EVENT \
+	_IOW(0xF6, 0xC5, struct lttng_kernel_abi_counter_event)
+
+#ifdef CONFIG_LTTNG_EXPERIMENTAL_COUNTER
+#define LTTNG_KERNEL_ABI_COUNTER_READ \
+	_IOWR(0xF6, 0xC6, struct lttng_kernel_abi_counter_read)
+#define LTTNG_KERNEL_ABI_COUNTER_AGGREGATE \
+	_IOWR(0xF6, 0xC7, struct lttng_kernel_abi_counter_aggregate)
+#define LTTNG_KERNEL_ABI_COUNTER_CLEAR \
+	_IOW(0xF6, 0xC8, struct lttng_kernel_abi_counter_clear)
+#endif	/* CONFIG_LTTNG_EXPERIMENTAL_COUNTER */
 
 /*
  * LTTng-specific ioctls for the lib ringbuffer.
@@ -472,6 +640,17 @@ struct lttng_kernel_abi_tracker_args {
 /* returns the stream instance id (invariant for the stream) */
 #define LTTNG_KERNEL_ABI_RING_BUFFER_INSTANCE_ID		_IOR(0xF6, 0x28, uint64_t)
 
+struct lttng_kernel_abi_ring_buffer_packet_flush_or_populate_packet_args {
+	/* Input fields */
+	__u64 packet; /* Pointer cast to __u64 */
+
+	/* Output fields */
+	__u64 packet_length;
+	__u64 packet_length_padded;
+	__u8 flush_done;
+	__u8 packet_populated;
+} __attribute__((packed));
+
 /*
  * Those ioctl numbers use the wrong direction, but are kept for ABI backward
  * compatibility.
