@@ -16,7 +16,8 @@
 #include <linux/kref.h>
 #include <linux/uuid.h>
 #include <linux/irq_work.h>
-#include <wrapper/uprobes.h>
+#include <linux/uprobes.h>
+
 #include <lttng/cpuhotplug.h>
 #include <lttng/tracer.h>
 #include <lttng/abi.h>
@@ -26,6 +27,7 @@
 #define lttng_is_signed_type(type)	(((type) -1) < (type) 1)
 
 struct lttng_kernel_channel_buffer;
+struct lttng_kernel_channel_counter;
 struct lttng_kernel_session;
 struct lttng_kernel_ring_buffer_ctx;
 
@@ -58,7 +60,35 @@ struct lttng_kernel_enum_entry {
 	struct lttng_kernel_enum_value start, end;	/* start and end are inclusive */
 	const char *string;
 	struct {
+		/*
+		 * If 1, then `start` and `end` above are irrelevant:
+		 * both the start and end values of this entry are
+		 * either:
+		 *
+		 * This is the first value:
+		 *     Zero.
+		 *
+		 * Otherwise:
+		 *     The effective end value of the previous entry
+		 *     plus one.
+		 *
+		 * This is only relevant when this entry is part of
+		 * `lttng_kernel_enum_desc::entries`; see
+		 * `struct lttng_kernel_enum_desc` to learn more.
+		 */
 		unsigned int is_auto:1;
+
+		/*
+		 * If 1, then this entry is the first within its entry
+		 * array to have the name `string` (field above). The
+		 * next immediate entries having the same name have
+		 * `is_first_in_group` set to 0.
+		 *
+		 * This is only relevant when this entry is part of
+		 * `lttng_kernel_enum_desc::sorted_entries`; see
+		 * `struct lttng_kernel_enum_desc` to learn more.
+		 */
+		unsigned int is_first_in_group:1;
 	} options;
 };
 
@@ -96,7 +126,7 @@ struct lttng_kernel_type_array {
 	struct lttng_kernel_type_common parent;
 	const struct lttng_kernel_type_common *elem_type;
 	unsigned int length;			/* Num. elems. */
-	unsigned int alignment;
+	unsigned int alignment;		/* Alignment in bytes before elements. */
 	enum lttng_kernel_string_encoding encoding;
 };
 
@@ -104,7 +134,7 @@ struct lttng_kernel_type_sequence {
 	struct lttng_kernel_type_common parent;
 	const char *length_name;	/* Length field name. If NULL, use previous field. */
 	const struct lttng_kernel_type_common *elem_type;
-	unsigned int alignment;		/* Alignment before elements. */
+	unsigned int alignment;		/* Alignment in bytes before elements. */
 	enum lttng_kernel_string_encoding encoding;
 };
 
@@ -112,7 +142,7 @@ struct lttng_kernel_type_struct {
 	struct lttng_kernel_type_common parent;
 	unsigned int nr_fields;
 	const struct lttng_kernel_event_field * const *fields;	/* Array of pointers to fields. */
-	unsigned int alignment;
+	unsigned int alignment;		/* Alignment in bits */
 };
 
 struct lttng_kernel_type_variant {
@@ -120,14 +150,48 @@ struct lttng_kernel_type_variant {
 	const char *tag_name;		/* Tag field name. If NULL, use previous field. */
 	const struct lttng_kernel_event_field * const *choices; /* Array of pointers to fields. */
 	unsigned int nr_choices;
-	unsigned int alignment;
+	unsigned int alignment;		/* Alignment in bytes */
 };
 
 struct lttng_kernel_enum_desc {
 	const char *name;
+
+	/*
+	 * `entries` below is the original array of enumeration entries,
+	 * as defined by the TP_ENUM_VALUES() user. This is left as is
+	 * to avoid changes to the TSDL output of which the enumeration
+	 * field class layout matches the LTTng-modules one.
+	 *
+	 * `sorted_entries` is a copy of the entry instances within
+	 * `entries`, but:
+	 *
+	 * • The entries are sorted by name
+	 *   (`lttng_kernel_enum_entry::string`).
+	 *
+	 * • The `options.is_auto` field of each entry is 0: the value
+	 *   range is always [`start`, `end`].
+	 *
+	 * • The `options.is_first_in_group` field of an entry E may be
+	 *   true to indicate that E is the first entry within the
+	 *   sorted entries to have its specific name.
+	 *
+	 * This helps with CTF 2 metadata stream production, where
+	 * the mappings are a map of unique names to arrays of ranges.
+	 *
+	 * `sorted_entries` is initially zero-initialized from Stage 2:
+	 * lttng_kernel_probe_register() needs to perform the copy,
+	 * automatic value resolution, and entry sorting.
+	 */
 	const struct lttng_kernel_enum_entry * const *entries;
+	struct lttng_kernel_enum_entry *sorted_entries;
+
+	/* Number of entries in `entries` and `sorted_entries` */
 	unsigned int nr_entries;
+
 	const struct lttng_kernel_probe_desc *probe_desc;
+
+	/* 1 if this describes a variant type tag */
+	int is_tag;
 };
 
 /* Event field description */
@@ -348,6 +412,7 @@ struct lttng_kernel_event_common_private;
 enum lttng_kernel_event_type {
 	LTTNG_KERNEL_EVENT_TYPE_RECORDER = 0,
 	LTTNG_KERNEL_EVENT_TYPE_NOTIFIER = 1,
+	LTTNG_KERNEL_EVENT_TYPE_COUNTER = 2
 };
 
 struct lttng_kernel_event_common {
@@ -373,6 +438,21 @@ struct lttng_kernel_event_recorder {
 	struct lttng_kernel_channel_buffer *chan;
 };
 
+struct lttng_kernel_event_counter_ctx {
+	int args_available;
+};
+
+struct lttng_kernel_event_counter_private;
+
+struct lttng_kernel_event_counter {
+	struct lttng_kernel_event_common parent;
+	struct lttng_kernel_event_counter_private *priv;	/* Private event counter interface */
+
+	struct lttng_kernel_channel_counter *chan;
+
+	int use_args;						/* Use input arguments. */
+};
+
 struct lttng_kernel_notification_ctx {
 	int eval_capture;					/* Capture evaluation available. */
 };
@@ -414,6 +494,7 @@ struct lttng_kernel_channel_buffer_ops {
 
 enum lttng_kernel_channel_type {
 	LTTNG_KERNEL_CHANNEL_TYPE_BUFFER = 0,
+	LTTNG_KERNEL_CHANNEL_TYPE_COUNTER = 1,
 };
 
 struct lttng_kernel_channel_common_private;
@@ -437,6 +518,25 @@ struct lttng_kernel_channel_buffer {
 	struct lttng_kernel_channel_buffer_ops *ops;
 };
 
+struct lttng_kernel_channel_counter;
+struct lttng_kernel_channel_counter_ops_private;
+
+struct lttng_kernel_channel_counter_ops {
+	struct lttng_kernel_channel_counter_ops_private *priv;	/* Private channel counter ops interface */
+
+	int (*counter_hit)(struct lttng_kernel_event_counter *event_counter,
+		const char *stack_data,
+		struct lttng_kernel_probe_ctx *probe_ctx,
+		struct lttng_kernel_event_counter_ctx *event_counter_ctx);
+};
+
+struct lttng_kernel_channel_counter {
+	struct lttng_kernel_channel_common parent;
+	struct lttng_kernel_channel_counter_private *priv;	/* Private channel counter interface */
+
+	struct lttng_kernel_channel_counter_ops *ops;
+};
+
 #define LTTNG_DYNAMIC_LEN_STACK_SIZE	128
 
 struct lttng_dynamic_len_stack {
@@ -483,4 +583,30 @@ void lttng_kernel_probe_unregister(struct lttng_kernel_probe_desc *desc);
 
 bool lttng_id_tracker_lookup(struct lttng_kernel_id_tracker_rcu *p, int id);
 
+static inline
+struct lttng_kernel_channel_common *lttng_kernel_get_chan_common_from_event_common(
+		struct lttng_kernel_event_common *event)
+{
+	switch (event->type) {
+	case LTTNG_KERNEL_EVENT_TYPE_RECORDER:
+	{
+		struct lttng_kernel_event_recorder *event_recorder =
+			container_of(event, struct lttng_kernel_event_recorder, parent);
+		struct lttng_kernel_channel_buffer *chan_buf = event_recorder->chan;
+
+		return &chan_buf->parent;
+	}
+	case LTTNG_KERNEL_EVENT_TYPE_COUNTER:
+	{
+		struct lttng_kernel_event_counter *event_counter =
+			container_of(event, struct lttng_kernel_event_counter, parent);
+		struct lttng_kernel_channel_counter *chan_counter = event_counter->chan;
+
+		return &chan_counter->parent;
+	}
+	default:
+		return NULL;
+	}
+}
+
 #endif /* _LTTNG_EVENTS_H */
