@@ -41,9 +41,9 @@ struct lttng_kernel_ring_buffer_client_cb {
 
 	/* Slow path only, at subbuffer switch */
 	size_t (*subbuffer_header_size) (void);
-	void (*buffer_begin) (struct lttng_kernel_ring_buffer *buf, u64 tsc,
+	void (*buffer_begin) (struct lttng_kernel_ring_buffer *buf, u64 timestamp,
 			      unsigned int subbuf_idx);
-	void (*buffer_end) (struct lttng_kernel_ring_buffer *buf, u64 tsc,
+	void (*buffer_end) (struct lttng_kernel_ring_buffer *buf, u64 timestamp,
 			    unsigned int subbuf_idx, unsigned long data_size,
 			    const struct lttng_kernel_ring_buffer_ctx *ctx);
 
@@ -82,17 +82,17 @@ struct lttng_kernel_ring_buffer_client_cb {
  *   with preemption disabled (lib_ring_buffer_get_cpu() and
  *   lib_ring_buffer_put_cpu()).
  *
- * RING_BUFFER_ALLOC_PER_CPU and RING_BUFFER_SYNC_GLOBAL :
- *   Per-cpu buffer with global synchronization. Tracing can be performed with
+ * RING_BUFFER_ALLOC_PER_CPU and RING_BUFFER_SYNC_PER_CHANNEL :
+ *   Per-cpu buffer with per-channel synchronization. Tracing can be performed with
  *   preemption enabled, statistically stays on the local buffers.
  *
- * RING_BUFFER_ALLOC_GLOBAL and RING_BUFFER_SYNC_PER_CPU :
+ * RING_BUFFER_ALLOC_PER_CHANNEL and RING_BUFFER_SYNC_PER_CPU :
  *   Should only be used for buffers belonging to a single thread or protected
  *   by mutual exclusion by the client. Note that periodical sub-buffer switch
  *   should be disabled in this kind of configuration.
  *
- * RING_BUFFER_ALLOC_GLOBAL and RING_BUFFER_SYNC_GLOBAL :
- *   Global shared buffer with global synchronization.
+ * RING_BUFFER_ALLOC_PER_CHANNEL and RING_BUFFER_SYNC_PER_CHANNEL :
+ *   Per-channel shared buffer with per-channel synchronization.
  *
  * wakeup:
  *
@@ -113,11 +113,11 @@ struct lttng_kernel_ring_buffer_client_cb {
 struct lttng_kernel_ring_buffer_config {
 	enum {
 		RING_BUFFER_ALLOC_PER_CPU,
-		RING_BUFFER_ALLOC_GLOBAL,
+		RING_BUFFER_ALLOC_PER_CHANNEL,
 	} alloc;
 	enum {
 		RING_BUFFER_SYNC_PER_CPU,	/* Wait-free */
-		RING_BUFFER_SYNC_GLOBAL,	/* Lock-free */
+		RING_BUFFER_SYNC_PER_CHANNEL,	/* Lock-free */
 	} sync;
 	enum {
 		RING_BUFFER_OVERWRITE,		/* Overwrite when buffer full */
@@ -151,10 +151,10 @@ struct lttng_kernel_ring_buffer_config {
 						 */
 	} wakeup;
 	/*
-	 * tsc_bits: timestamp bits saved at each record.
+	 * timestamp_bits: timestamp bits saved at each record.
 	 *   0 and 64 disable the timestamp compression scheme.
 	 */
-	unsigned int tsc_bits;
+	unsigned int timestamp_bits;
 	struct lttng_kernel_ring_buffer_client_cb cb;
 };
 
@@ -182,7 +182,7 @@ struct lttng_kernel_ring_buffer_ctx_private {
 						 * prior to record header alignment
 						 * padding.
 						 */
-	u64 tsc;				/* time-stamp counter value */
+	u64 timestamp;				/* time-stamp counter value */
 	unsigned int rflags;			/* reservation flags */
 
 	struct lttng_kernel_ring_buffer *buf;	/*
@@ -215,7 +215,7 @@ struct lttng_kernel_ring_buffer_ctx {
 	void *client_priv;		/* Ring buffer client private data */
 
 	size_t data_size;		/* size of payload */
-	int largest_align;		/*
+	size_t largest_align;		/*
 					 * alignment of the largest element
 					 * in the payload
 					 */
@@ -232,7 +232,7 @@ struct lttng_kernel_ring_buffer_ctx {
 static inline
 void lib_ring_buffer_ctx_init(struct lttng_kernel_ring_buffer_ctx *ctx,
 			      void *client_priv,
-			      size_t data_size, int largest_align,
+			      size_t data_size, size_t largest_align,
 			      struct lttng_kernel_probe_ctx *probe_ctx)
 {
 	ctx->client_priv = client_priv;
@@ -244,18 +244,18 @@ void lib_ring_buffer_ctx_init(struct lttng_kernel_ring_buffer_ctx *ctx,
 /*
  * Reservation flags.
  *
- * RING_BUFFER_RFLAG_FULL_TSC
+ * RING_BUFFER_RFLAG_FULL_TIMESTAMP
  *
  * This flag is passed to record_header_size() and to the primitive used to
  * write the record header. It indicates that the full 64-bit time value is
  * needed in the record header. If this flag is not set, the record header needs
- * only to contain "tsc_bits" bit of time value.
+ * only to contain "timestamp_bits" bit of time value.
  *
  * Reservation flags can be added by the client, starting from
  * "(RING_BUFFER_FLAGS_END << 0)". It can be used to pass information from
  * record_header_size() to lib_ring_buffer_write_record_header().
  */
-#define	RING_BUFFER_RFLAG_FULL_TSC		(1U << 0)
+#define	RING_BUFFER_RFLAG_FULL_TIMESTAMP	(1U << 0)
 #define RING_BUFFER_RFLAG_END			(1U << 1)
 
 #ifndef LTTNG_TRACER_CORE_H
@@ -319,7 +319,7 @@ int lib_ring_buffer_check_config(const struct lttng_kernel_ring_buffer_config *c
 			     unsigned int switch_timer_interval,
 			     unsigned int read_timer_interval)
 {
-	if (config->alloc == RING_BUFFER_ALLOC_GLOBAL
+	if (config->alloc == RING_BUFFER_ALLOC_PER_CHANNEL
 	    && config->sync == RING_BUFFER_SYNC_PER_CPU
 	    && switch_timer_interval)
 		return -EINVAL;
