@@ -15,6 +15,7 @@
 #include <ringbuffer/config.h>
 #include <ringbuffer/backend_types.h>
 #include <ringbuffer/frontend_types.h>
+#include <lttng/abi.h>
 #include <lttng/prio_heap.h>	/* For per-CPU read-side iterator */
 
 /* Buffer offset macros */
@@ -71,62 +72,63 @@ unsigned long subbuf_index(unsigned long offset, struct lttng_kernel_ring_buffer
 }
 
 /*
- * Last TSC comparison functions. Check if the current TSC overflows tsc_bits
- * bits from the last TSC read. When overflows are detected, the full 64-bit
- * timestamp counter should be written in the record header. Reads and writes
- * last_tsc atomically.
+ * Last timestamp comparison functions. Check if the current timestamp
+ * overflows timestamp_bits bits from the last timestamp read. When
+ * overflows are detected, the full 64-bit timestamp counter should be
+ * written in the record header. Reads and writes last_timestamp
+ * atomically.
  */
 
 #if (BITS_PER_LONG == 32)
 static inline
-void save_last_tsc(const struct lttng_kernel_ring_buffer_config *config,
-		   struct lttng_kernel_ring_buffer *buf, u64 tsc)
+void save_last_timestamp(const struct lttng_kernel_ring_buffer_config *config,
+		   struct lttng_kernel_ring_buffer *buf, u64 timestamp)
 {
-	if (config->tsc_bits == 0 || config->tsc_bits == 64)
+	if (config->timestamp_bits == 0 || config->timestamp_bits == 64)
 		return;
 
 	/*
 	 * Ensure the compiler performs this update in a single instruction.
 	 */
-	v_set(config, &buf->last_tsc, (unsigned long)(tsc >> config->tsc_bits));
+	v_set(config, &buf->last_timestamp, (unsigned long)(timestamp >> config->timestamp_bits));
 }
 
 static inline
-int last_tsc_overflow(const struct lttng_kernel_ring_buffer_config *config,
-		      struct lttng_kernel_ring_buffer *buf, u64 tsc)
+int last_timestamp_overflow(const struct lttng_kernel_ring_buffer_config *config,
+		      struct lttng_kernel_ring_buffer *buf, u64 timestamp)
 {
-	unsigned long tsc_shifted;
+	unsigned long timestamp_shifted;
 
-	if (config->tsc_bits == 0 || config->tsc_bits == 64)
+	if (config->timestamp_bits == 0 || config->timestamp_bits == 64)
 		return 0;
 
-	tsc_shifted = (unsigned long)(tsc >> config->tsc_bits);
-	if (unlikely(tsc_shifted
-		     - (unsigned long)v_read(config, &buf->last_tsc)))
+	timestamp_shifted = (unsigned long)(timestamp >> config->timestamp_bits);
+	if (unlikely(timestamp_shifted
+		     - (unsigned long)v_read(config, &buf->last_timestamp)))
 		return 1;
 	else
 		return 0;
 }
 #else
 static inline
-void save_last_tsc(const struct lttng_kernel_ring_buffer_config *config,
-		   struct lttng_kernel_ring_buffer *buf, u64 tsc)
+void save_last_timestamp(const struct lttng_kernel_ring_buffer_config *config,
+		   struct lttng_kernel_ring_buffer *buf, u64 timestamp)
 {
-	if (config->tsc_bits == 0 || config->tsc_bits == 64)
+	if (config->timestamp_bits == 0 || config->timestamp_bits == 64)
 		return;
 
-	v_set(config, &buf->last_tsc, (unsigned long)tsc);
+	v_set(config, &buf->last_timestamp, (unsigned long)timestamp);
 }
 
 static inline
-int last_tsc_overflow(const struct lttng_kernel_ring_buffer_config *config,
-		      struct lttng_kernel_ring_buffer *buf, u64 tsc)
+int last_timestamp_overflow(const struct lttng_kernel_ring_buffer_config *config,
+		      struct lttng_kernel_ring_buffer *buf, u64 timestamp)
 {
-	if (config->tsc_bits == 0 || config->tsc_bits == 64)
+	if (config->timestamp_bits == 0 || config->timestamp_bits == 64)
 		return 0;
 
-	if (unlikely((tsc - v_read(config, &buf->last_tsc))
-		     >> config->tsc_bits))
+	if (unlikely((timestamp - v_read(config, &buf->last_timestamp))
+		     >> config->timestamp_bits))
 		return 1;
 	else
 		return 0;
@@ -155,6 +157,14 @@ void lib_ring_buffer_switch_remote(struct lttng_kernel_ring_buffer *buf);
 extern
 void lib_ring_buffer_switch_remote_empty(struct lttng_kernel_ring_buffer *buf);
 extern
+int lib_ring_buffer_switch_remote_or_populate_packet(const struct lttng_kernel_ring_buffer_config *config,
+		struct lttng_kernel_ring_buffer *buf,
+		void __user *packet,
+		u64 *packet_length,
+		u64 *packet_length_padded,
+		bool *flush_done,
+		bool *packet_populated);
+extern
 void lib_ring_buffer_clear(struct lttng_kernel_ring_buffer *buf);
 
 /* Buffer write helpers */
@@ -264,7 +274,7 @@ int lib_ring_buffer_reserve_committed(const struct lttng_kernel_ring_buffer_conf
 }
 
 /*
- * Receive end of subbuffer TSC as parameter. It has been read in the
+ * Receive end of subbuffer timestamp as parameter. It has been read in the
  * space reservation loop of either reserve or switch, which ensures it
  * progresses monotonically with event records in the buffer. Therefore,
  * it ensures that the end timestamp of a subbuffer is <= begin
@@ -328,6 +338,15 @@ extern int lib_ring_buffer_create(struct lttng_kernel_ring_buffer *buf,
 				  struct channel_backend *chanb, int cpu);
 extern void lib_ring_buffer_free(struct lttng_kernel_ring_buffer *buf);
 
+extern int lib_ring_buffer_packet_initialize(const struct lttng_kernel_ring_buffer_config *config,
+		struct lttng_kernel_ring_buffer *buf,
+		void __user *packet,
+		u64 begin_timestamp,
+		u64 end_timestamp,
+		u64 sequence_number,
+		u64 *packet_length,
+		u64 *packet_length_padded);
+
 /* Keep track of trap nesting inside ring buffer code */
 DECLARE_PER_CPU(unsigned int, lib_ring_buffer_nesting);
 
