@@ -18,7 +18,7 @@
 #include <ringbuffer/frontend_types.h>
 
 #define LTTNG_COMPACT_EVENT_BITS	5
-#define LTTNG_COMPACT_TSC_BITS		27
+#define LTTNG_COMPACT_TIMESTAMP_BITS	27
 
 static struct lttng_transport lttng_relay_transport;
 
@@ -149,7 +149,7 @@ size_t record_header_size(const struct lttng_kernel_ring_buffer_config *config,
 	case 1:	/* compact */
 		padding = lib_ring_buffer_align(offset, lttng_alignof(uint32_t));
 		offset += padding;
-		if (!(ctx->priv.rflags & (RING_BUFFER_RFLAG_FULL_TSC | LTTNG_RFLAG_EXTENDED))) {
+		if (!(ctx->priv.rflags & (RING_BUFFER_RFLAG_FULL_TIMESTAMP | LTTNG_RFLAG_EXTENDED))) {
 			offset += sizeof(uint32_t);	/* id and timestamp */
 		} else {
 			/* Minimum space taken by LTTNG_COMPACT_EVENT_BITS id */
@@ -165,7 +165,7 @@ size_t record_header_size(const struct lttng_kernel_ring_buffer_config *config,
 		padding = lib_ring_buffer_align(offset, lttng_alignof(uint16_t));
 		offset += padding;
 		offset += sizeof(uint16_t);
-		if (!(ctx->priv.rflags & (RING_BUFFER_RFLAG_FULL_TSC | LTTNG_RFLAG_EXTENDED))) {
+		if (!(ctx->priv.rflags & (RING_BUFFER_RFLAG_FULL_TIMESTAMP | LTTNG_RFLAG_EXTENDED))) {
 			offset += lib_ring_buffer_align(offset, lttng_alignof(uint32_t));
 			offset += sizeof(uint32_t);	/* timestamp */
 		} else {
@@ -223,14 +223,14 @@ void lttng_write_event_header(const struct lttng_kernel_ring_buffer_config *conf
 				event_id);
 		bt_bitfield_write(&id_time, uint32_t,
 				LTTNG_COMPACT_EVENT_BITS,
-				LTTNG_COMPACT_TSC_BITS,
-				ctx->priv.tsc);
+				LTTNG_COMPACT_TIMESTAMP_BITS,
+				ctx->priv.timestamp);
 		lib_ring_buffer_write(config, ctx, &id_time, sizeof(id_time));
 		break;
 	}
 	case 2:	/* large */
 	{
-		uint32_t timestamp = (uint32_t) ctx->priv.tsc;
+		uint32_t timestamp = (uint32_t) ctx->priv.timestamp;
 		uint16_t id = event_id;
 
 		lib_ring_buffer_write(config, ctx, &id, sizeof(id));
@@ -260,7 +260,7 @@ void lttng_write_event_header_slow(const struct lttng_kernel_ring_buffer_config
 
 	switch (lttng_chan->priv->header_type) {
 	case 1:	/* compact */
-		if (!(ctx->priv.rflags & (RING_BUFFER_RFLAG_FULL_TSC | LTTNG_RFLAG_EXTENDED))) {
+		if (!(ctx->priv.rflags & (RING_BUFFER_RFLAG_FULL_TIMESTAMP | LTTNG_RFLAG_EXTENDED))) {
 			uint32_t id_time = 0;
 
 			bt_bitfield_write(&id_time, uint32_t,
@@ -269,11 +269,11 @@ void lttng_write_event_header_slow(const struct lttng_kernel_ring_buffer_config
 					event_id);
 			bt_bitfield_write(&id_time, uint32_t,
 					LTTNG_COMPACT_EVENT_BITS,
-					LTTNG_COMPACT_TSC_BITS, ctx->priv.tsc);
+					LTTNG_COMPACT_TIMESTAMP_BITS, ctx->priv.timestamp);
 			lib_ring_buffer_write(config, ctx, &id_time, sizeof(id_time));
 		} else {
 			uint8_t id = 0;
-			uint64_t timestamp = ctx->priv.tsc;
+			uint64_t timestamp = ctx->priv.timestamp;
 
 			bt_bitfield_write(&id, uint8_t,
 					0,
@@ -289,8 +289,8 @@ void lttng_write_event_header_slow(const struct lttng_kernel_ring_buffer_config
 		break;
 	case 2:	/* large */
 	{
-		if (!(ctx->priv.rflags & (RING_BUFFER_RFLAG_FULL_TSC | LTTNG_RFLAG_EXTENDED))) {
-			uint32_t timestamp = (uint32_t) ctx->priv.tsc;
+		if (!(ctx->priv.rflags & (RING_BUFFER_RFLAG_FULL_TIMESTAMP | LTTNG_RFLAG_EXTENDED))) {
+			uint32_t timestamp = (uint32_t) ctx->priv.timestamp;
 			uint16_t id = event_id;
 
 			lib_ring_buffer_write(config, ctx, &id, sizeof(id));
@@ -298,7 +298,7 @@ void lttng_write_event_header_slow(const struct lttng_kernel_ring_buffer_config
 			lib_ring_buffer_write(config, ctx, &timestamp, sizeof(timestamp));
 		} else {
 			uint16_t id = 65535;
-			uint64_t timestamp = ctx->priv.tsc;
+			uint64_t timestamp = ctx->priv.timestamp;
 
 			lib_ring_buffer_write(config, ctx, &id, sizeof(id));
 			/* Align extended struct on largest member */
@@ -346,7 +346,7 @@ static size_t client_packet_header_size(void)
 	return offsetof(struct packet_header, ctx.header_end);
 }
 
-static void client_buffer_begin(struct lttng_kernel_ring_buffer *buf, u64 tsc,
+static void client_buffer_begin(struct lttng_kernel_ring_buffer *buf, u64 timestamp,
 				unsigned int subbuf_idx)
 {
 	struct lttng_kernel_ring_buffer_channel *chan = buf->backend.chan;
@@ -361,7 +361,7 @@ static void client_buffer_begin(struct lttng_kernel_ring_buffer *buf, u64 tsc,
 	memcpy(header->uuid, session->priv->uuid.b, sizeof(session->priv->uuid));
 	header->stream_id = lttng_chan->priv->id;
 	header->stream_instance_id = buf->backend.cpu;
-	header->ctx.timestamp_begin = tsc;
+	header->ctx.timestamp_begin = timestamp;
 	header->ctx.timestamp_end = 0;
 	header->ctx.content_size = ~0ULL; /* for debugging */
 	header->ctx.packet_size = ~0ULL;
@@ -376,7 +376,7 @@ static void client_buffer_begin(struct lttng_kernel_ring_buffer *buf, u64 tsc,
  * offset is assumed to never be 0 here : never deliver a completely empty
  * subbuffer. data_size is between 1 and subbuf_size.
  */
-static void client_buffer_end(struct lttng_kernel_ring_buffer *buf, u64 tsc,
+static void client_buffer_end(struct lttng_kernel_ring_buffer *buf, u64 timestamp,
 			      unsigned int subbuf_idx, unsigned long data_size,
 			      const struct lttng_kernel_ring_buffer_ctx *ctx)
 {
@@ -385,17 +385,13 @@ static void client_buffer_end(struct lttng_kernel_ring_buffer *buf, u64 tsc,
 		(struct packet_header *)
 			lib_ring_buffer_offset_address(&buf->backend,
 				subbuf_idx * chan->backend.subbuf_size);
-	unsigned long records_lost = 0;
 
-	header->ctx.timestamp_end = tsc;
+	header->ctx.timestamp_end = timestamp;
 	header->ctx.content_size =
 		(uint64_t) data_size * CHAR_BIT;		/* in bits */
 	header->ctx.packet_size =
 		(uint64_t) PAGE_ALIGN(data_size) * CHAR_BIT;	/* in bits */
-	records_lost += lib_ring_buffer_get_records_lost_full(&client_config, ctx);
-	records_lost += lib_ring_buffer_get_records_lost_wrap(&client_config, ctx);
-	records_lost += lib_ring_buffer_get_records_lost_big(&client_config, ctx);
-	header->ctx.events_discarded = records_lost;
+	header->ctx.events_discarded = buf->commit_cold[subbuf_idx].end_events_discarded;
 }
 
 static int client_buffer_create(struct lttng_kernel_ring_buffer *buf, void *priv,
@@ -506,6 +502,48 @@ int client_instance_id(const struct lttng_kernel_ring_buffer_config *config,
 	return 0;
 }
 
+
+static
+int client_user_packet_initialize(const struct lttng_kernel_ring_buffer_config *config,
+		struct lttng_kernel_ring_buffer *bufb,
+		void __user *packet,
+		u64 timestamp_begin,
+		u64 timestamp_end,
+		u64 sequence_number,
+		u64 *packet_length,
+		u64 *packet_length_padded)
+{
+	struct lttng_kernel_channel_buffer *lttng_chan = channel_get_private(bufb->backend.chan);
+	struct lttng_kernel_ring_buffer_channel *chan = bufb->backend.chan;
+	struct packet_header packet_header = {};
+	int ret;
+
+	if (!chan)
+		return -EINVAL;
+
+	/*
+	 * See client_buffer_begin()
+	 */
+	packet_header.magic = CTF_MAGIC_NUMBER;
+	packet_header.stream_id = lttng_chan->priv->id;
+	packet_header.stream_instance_id = bufb->backend.cpu;
+
+	packet_header.ctx.content_size = client_packet_header_size() * CHAR_BIT;
+	packet_header.ctx.packet_size = client_packet_header_size() * CHAR_BIT;
+	packet_header.ctx.cpu_id = bufb->backend.cpu;
+	packet_header.ctx.timestamp_begin = timestamp_begin;
+	packet_header.ctx.timestamp_end = timestamp_end;
+	packet_header.ctx.packet_seq_num = sequence_number;
+
+	ret = copy_to_user(packet, &packet_header, sizeof(struct packet_header));
+	if (ret)
+		return -EFAULT;
+
+	*packet_length = client_packet_header_size();
+	*packet_length_padded = client_packet_header_size();
+	return ret;
+}
+
 static const struct lttng_kernel_ring_buffer_config client_config = {
 	.cb.ring_buffer_clock_read = client_ring_buffer_clock_read,
 	.cb.record_header_size = client_record_header_size,
@@ -515,7 +553,7 @@ static const struct lttng_kernel_ring_buffer_config client_config = {
 	.cb.buffer_create = client_buffer_create,
 	.cb.buffer_finalize = client_buffer_finalize,
 
-	.tsc_bits = LTTNG_COMPACT_TSC_BITS,
+	.timestamp_bits = LTTNG_COMPACT_TIMESTAMP_BITS,
 	.alloc = RING_BUFFER_ALLOC_PER_CPU,
 	.sync = RING_BUFFER_SYNC_PER_CPU,
 	.mode = RING_BUFFER_MODE_TEMPLATE,
@@ -616,7 +654,7 @@ int lttng_event_reserve(struct lttng_kernel_ring_buffer_ctx *ctx)
 	cpu = lib_ring_buffer_get_cpu(&client_config);
 	if (unlikely(cpu < 0))
 		return -EPERM;
-	event_id = event_recorder->priv->id;
+	event_id = (uint32_t)event_recorder->priv->parent.id;
 	memset(&ctx->priv, 0, sizeof(ctx->priv));
 	ctx->priv.chan = lttng_chan->priv->rb_chan;
 	ctx->priv.reserve_cpu = cpu;
@@ -766,6 +804,7 @@ static struct lttng_transport lttng_relay_transport = {
 			.current_timestamp = client_current_timestamp,
 			.sequence_number = client_sequence_number,
 			.instance_id = client_instance_id,
+			.user_packet_initialize = client_user_packet_initialize,
 		}),
 		.event_reserve = lttng_event_reserve,
 		.event_commit = lttng_event_commit,
