@@ -22,6 +22,7 @@
 #include <linux/proc_fs.h>
 #include <linux/file.h>
 #include <linux/interrupt.h>
+#include <linux/irq.h>
 #include <linux/irqnr.h>
 #include <linux/netdevice.h>
 #include <linux/inetdevice.h>
@@ -39,18 +40,10 @@
 #include <wrapper/cpu.h>
 #include <wrapper/irqdesc.h>
 #include <wrapper/fdtable.h>
-#include <wrapper/namespace.h>
-#include <wrapper/irq.h>
 #include <wrapper/tracepoint.h>
-#include <wrapper/genhd.h>
-#include <wrapper/file.h>
-#include <wrapper/fdtable.h>
+#include <wrapper/blkdev.h>
 #include <wrapper/sched.h>
 
-#ifdef CONFIG_LTTNG_HAS_LIST_IRQ
-#include <linux/irq.h>
-#endif
-
 /* Define the tracepoints, but do not build the probes */
 #define CREATE_TRACE_POINTS
 #define TRACE_INCLUDE_PATH instrumentation/events
@@ -483,7 +476,7 @@ void lttng_enumerate_files(struct lttng_kernel_session *session,
 {
 	struct lttng_fd_ctx ctx = { .page = tmp, .session = session, .files = files, };
 
-	lttng_iterate_fd(files, 0, lttng_dump_one_fd, &ctx);
+	iterate_fd(files, 0, lttng_dump_one_fd, &ctx);
 }
 
 #ifdef LTTNG_HAVE_STATEDUMP_CPU_TOPOLOGY
@@ -532,7 +525,7 @@ void lttng_enumerate_task_vm_maps(struct lttng_kernel_session *session,
 		down_read(&mm->mmap_sem);
 		while (map) {
 			if (map->vm_file)
-				ino = map->vm_file->lttng_f_dentry->d_inode->i_ino;
+				ino = map->vm_file->f_path.dentry->d_inode->i_ino;
 			else
 				ino = 0;
 			trace_lttng_statedump_vm_map(session, p, map, ino);
@@ -556,8 +549,6 @@ int lttng_enumerate_vm_maps(struct lttng_kernel_session *session)
 }
 #endif
 
-#ifdef CONFIG_LTTNG_HAS_LIST_IRQ
-
 static
 int lttng_list_interrupts(struct lttng_kernel_session *session)
 {
@@ -584,13 +575,6 @@ int lttng_list_interrupts(struct lttng_kernel_session *session)
 	return 0;
 #undef irq_to_desc
 }
-#else
-static inline
-int lttng_list_interrupts(struct lttng_kernel_session *session)
-{
-	return 0;
-}
-#endif
 
 /*
  * Statedump the task's namespaces using the proc filesystem inode number as
@@ -635,24 +619,11 @@ void lttng_statedump_process_ns(struct lttng_kernel_session *session,
 		 * paranoid behavior of
 		 * trace_lttng_statedump_process_user_ns().
 		 */
-		user_ns = user_ns ? user_ns->lttng_user_ns_parent : NULL;
+		user_ns = user_ns ? user_ns->parent : NULL;
 	} while (user_ns);
 
-	/*
-	 * Back and forth on locking strategy within Linux upstream for nsproxy.
-	 * See Linux upstream commit 728dba3a39c66b3d8ac889ddbe38b5b1c264aec3
-	 * "namespaces: Use task_lock and not rcu to protect nsproxy"
-	 * for details.
-	 */
-#if (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(3,17,0) || \
-		LTTNG_UBUNTU_KERNEL_RANGE(3,13,11,36, 3,14,0,0) || \
-		LTTNG_UBUNTU_KERNEL_RANGE(3,16,1,11, 3,17,0,0) || \
-		LTTNG_RHEL_KERNEL_RANGE(3,10,0,229,13,0, 3,11,0,0,0,0))
 	proxy = p->nsproxy;
-#else
-	rcu_read_lock();
-	proxy = task_nsproxy(p);
-#endif
+
 	if (proxy) {
 #if (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(4,6,0))
 		trace_lttng_statedump_process_cgroup_ns(session, p, proxy->cgroup_ns);
@@ -668,14 +639,6 @@ void lttng_statedump_process_ns(struct lttng_kernel_session *session,
 		trace_lttng_statedump_process_time_ns(session, p, proxy->time_ns);
 #endif
 	}
-#if (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(3,17,0) || \
-		LTTNG_UBUNTU_KERNEL_RANGE(3,13,11,36, 3,14,0,0) || \
-		LTTNG_UBUNTU_KERNEL_RANGE(3,16,1,11, 3,17,0,0) || \
-		LTTNG_RHEL_KERNEL_RANGE(3,10,0,229,13,0, 3,11,0,0,0,0))
-	/* (nothing) */
-#else
-	rcu_read_unlock();
-#endif
 }
 
 static
@@ -842,13 +805,6 @@ EXPORT_SYMBOL_GPL(lttng_statedump_start);
 static
 int __init lttng_statedump_init(void)
 {
-	/*
-	 * Allow module to load even if the fixup cannot be done. This
-	 * will allow seemless transition when the underlying issue fix
-	 * is merged into the Linux kernel, and when tracepoint.c
-	 * "tracepoint_module_notify" is turned into a static function.
-	 */
-	(void) wrapper_lttng_fixup_sig(THIS_MODULE);
 	return 0;
 }
 
